@@ -2,12 +2,13 @@ from typing import Any, Callable, Dict, List, Tuple, Union, Optional, AsyncGener
 import asyncio
 import logging
 from contextlib import asynccontextmanager
-from fastapi import FastAPI
+from fastapi import FastAPI, applications
 from pydantic import BaseModel
 from sycommon.config.Config import SingletonMeta
 from sycommon.models.mqlistener_config import RabbitMQListenerConfig
 from sycommon.models.mqsend_config import RabbitMQSendConfig
 from sycommon.rabbitmq.rabbitmq_service import RabbitMQService
+from sycommon.tools.docs import custom_redoc_html, custom_swagger_ui_html
 
 
 class Services(metaclass=SingletonMeta):
@@ -53,6 +54,9 @@ class Services(metaclass=SingletonMeta):
         # 保存应用实例和配置
         cls._app = app
         cls._config = config
+        # 设置文档
+        applications.get_swagger_ui_html = custom_swagger_ui_html
+        applications.get_redoc_html = custom_redoc_html
 
         # 立即配置非异步服务（在应用启动前）
         if middleware:
@@ -125,11 +129,7 @@ class Services(metaclass=SingletonMeta):
         has_listeners: bool = False,
         has_senders: bool = False,
     ):
-        """异步设置MQ相关服务，保存发送器和监听器存在状态"""
-        # 保存状态到类变量
-        Services._has_listeners = has_listeners
-        Services._has_senders = has_senders
-
+        """异步设置MQ相关服务"""
         # 初始化RabbitMQ服务，传递状态
         RabbitMQService.init(self._config, has_listeners, has_senders)
 
@@ -141,6 +141,13 @@ class Services(metaclass=SingletonMeta):
         if rabbitmq_listeners:
             await self._setup_listeners_async(rabbitmq_listeners, has_senders)
 
+        # 验证初始化结果
+        if has_listeners:
+            listener_count = len(RabbitMQService._clients)
+            logging.info(f"监听器初始化完成，共启动 {listener_count} 个消费者")
+            if listener_count == 0:
+                logging.warning("未成功初始化任何监听器，请检查配置")
+
     async def _setup_senders_async(self, rabbitmq_senders, has_listeners: bool):
         Services._registered_senders = [
             sender.queue_name for sender in rabbitmq_senders]
@@ -158,7 +165,7 @@ class Services(metaclass=SingletonMeta):
         queue_name: str,
         data: Union[str, Dict[str, Any], BaseModel, None],
         max_retries: int = 3,
-        retry_delay: float = 1.0, ** kwargs
+        retry_delay: float = 1.0, **kwargs
     ) -> None:
         """发送消息，添加重试机制"""
         if not cls._initialized or not cls._loop:
@@ -168,7 +175,7 @@ class Services(metaclass=SingletonMeta):
         for attempt in range(max_retries):
             try:
                 if queue_name not in cls._registered_senders:
-                    cls._registered_senders = RabbitMQService.sender_client_names
+                    cls._registered_senders = RabbitMQService._sender_client_names
                     if queue_name not in cls._registered_senders:
                         raise ValueError(f"发送器 {queue_name} 未注册")
 
@@ -176,7 +183,7 @@ class Services(metaclass=SingletonMeta):
                 if not sender:
                     raise ValueError(f"发送器 '{queue_name}' 不存在")
 
-                await RabbitMQService.send_message(data, queue_name, **kwargs)
+                await RabbitMQService.send_message(data, queue_name, ** kwargs)
                 logging.info(f"消息发送成功（尝试 {attempt+1}/{max_retries}）")
                 return
 
